@@ -3,10 +3,10 @@ import numpy as np
 import dask.array as da
 import SimpleITK as sitk
 import ClusterWrap
-import CircuitSeeker.stitch as stitch
 import CircuitSeeker.utility as ut
 import greedypy.greedypy_registration_method as grm
 from scipy.ndimage import minimum_filter, gaussian_filter
+from dask_stitch.local_affine import local_affines_to_field
 
 
 def configure_irm(
@@ -221,14 +221,11 @@ def piecewise_affine_align(
     blocksize = np.ceil(blocksize).astype(np.int16)
     overlaps = blocksize // 2
 
-    # set cluster defaults
-    if 'cores' not in cluster_kwargs.keys():
-        cluster_kwargs['cores'] = 2
-
     # set up cluster
     with ClusterWrap.cluster(**cluster_kwargs) as cluster:
 
         # construct dask array versions of objects
+        # extra dimensions to match field of affine matrices
         fix_da = da.from_array(fix)
         mov_da = da.from_array(mov)
         fm_da = da.from_array(fix_mask)
@@ -243,41 +240,36 @@ def piecewise_affine_align(
         fm_da = da.pad(fm_da, pads).rechunk(tuple(blocksize))
         mm_da = da.pad(mm_da, pads).rechunk(tuple(blocksize))
 
-        # closure for rigid align function
-        def single_rigid_align(fix, mov, fm, mm):
+        # closure for affine alignment
+        def single_affine_align(fix, mov, fm, mm, block_info=None):
+            # rigid alignment
             rigid = affine_align(
                 fix, mov, fix_spacing, mov_spacing,
                 fix_mask=fm, mov_mask=mm,
+                rigid=True,
                 **kwargs,
             )
-            return rigid.reshape((1,1,1,4,4))
-
-        # rigid align all chunks
-        rigids = da.map_overlap(
-            single_rigid_align, fix_da, mov_da, fm_da, mm_da,
-            depth=tuple(overlaps),
-            dtype=np.float32,
-            boundary='none',
-            trim=False,
-            align_arrays=False,
-            new_axis=[3,4],
-            chunks=[1,1,1,4,4],
-        ).compute()
-
-        # closure for affine align function
-        def single_affine_align(fix, mov, fm, mm, block_info=None):
-            block_idx = block_info[0]['chunk-location']
-            rigid = rigids[block_idx[0], block_idx[1], block_idx[2]]
+            # affine alignment
             affine = affine_align(
                 fix, mov, fix_spacing, mov_spacing,
-                fix_mask=fm, mov_mask=mm, rigid=rigid,
+                fix_mask=fm, mov_mask=mm,
+                initial_transform=rigid,
                 **kwargs,
             )
+            # correct for block origin
+            idx = block_info[0]['chunk-location']
+            origin = np.maximum(0, blocksize * idx - overlaps)
+            origin = origin * fix_spacing
+            tl, tr = np.eye(4), np.eye(4)
+            tl[:3, -1], tr[:3, -1] = origin, -origin
+            affine = np.matmul(tl, np.matmul(affine, tr))
+            # return result
             return affine.reshape((1,1,1,4,4))
 
         # affine align all chunks
         affines = da.map_overlap(
-            single_affine_align, fix_da, mov_da, fm_da, mm_da,
+            single_affine_align,
+            fix_da, mov_da, fm_da, mm_da,
             depth=tuple(overlaps),
             dtype=np.float32,
             boundary='none',
@@ -288,8 +280,9 @@ def piecewise_affine_align(
         ).compute()
 
         # stitch local affines into displacement field
-        field = stitch.local_affine_to_displacement(
-            fix.shape, fix_spacing, affines, blocksize,
+        field = local_affines_to_field(
+            fix.shape, fix_spacing,
+            affines, blocksize, overlaps,
         ).compute()
 
         return field
